==> octo_train-0.1.0.tar.gz: octo_train-0.1.0/README.md <==
# octo-train

[![Build Status](https://travis-ci.org/dankondr/octo-train.svg?branch=master)](https://travis-ci.org/dankondr/octo-train)
[![codecov](https://codecov.io/gh/dankondr/octo-train/branch/master/graph/badge.svg)](https://codecov.io/gh/dankondr/octo-train)

![octo-train](https://raw.githubusercontent.com/dankondr/octo-train/master/art/octo_train.gif)

> Simple CLI client for your programming accomplishments.

## About

This project provides you with comfortable interface for developing your programming skills with CodeForces and Project Euler 🎉

## Install

```bash
$ pip install octo-train
```

## Usage

```bash
$ octo-train
```

### Creating new user

On first launch application will ask you to provide some info.

#### Name

Just your name to get personalized experience. ☺️

#### CodeForces level

To start your CodeForces journey with octo-train you must specify level of problems you can solve.

You can either specify 0 and start from the easiest ones (you can change it in the settings later) or go to codeforces/archive and find appropriate level for you.


>⚠️ Problems level is the number specified on the right from problem's name. It starts at 500 and goes up to 3000 with step of 100.

![problems level](https://raw.githubusercontent.com/dankondr/octo-train/master/art/cf_problem_level.png)

#### CodeForces daily goal

The minimal number of problems you want to solve every day.

#### Project Euler level

With Project Euler you must specify level of problems you can solve too.

You can either specify 0 and start from the easiest ones (you can change it in the settings later) or go to projecteuler/archives and find appropriate level for you.


>⚠️ Problems level is the orange bar on the right from problem's name. Hover to see the number. It starts at 5% and goes up to 100%.

![problems level](https://raw.githubusercontent.com/dankondr/octo-train/master/art/pe_problem_level.png)

#### Project Euler daily goal

The minimal number of problems you want to solve every day.

### Get the problem

In menu select which kind of problems you want to solve.

![octo-train menu](https://raw.githubusercontent.com/dankondr/octo-train/master/art/octo_train_menu.gif)

### See the stats

Show your stats as a problem-solver.

![octo-train stats](https://raw.githubusercontent.com/dankondr/octo-train/master/art/octo_train_stats.gif)

==> octo_train-0.1.2.tar.gz: octo_train-0.1.2/README.md <==
# octo-train

[![Build Status](https://travis-ci.org/dankondr/octo-train.svg?branch=master)](https://travis-ci.org/dankondr/octo-train)
[![codecov](https://codecov.io/gh/dankondr/octo-train/branch/master/graph/badge.svg)](https://codecov.io/gh/dankondr/octo-train)

![octo-train](https://raw.githubusercontent.com/dankondr/octo-train/master/art/octo-train.gif)

> Simple CLI client for your programming accomplishments.

## About

This project provides you with comfortable interface for developing your programming skills with CodeForces and Project Euler 🎉

## Install

```bash
$ pip install octo-train
```

## Usage

```bash
$ octo-train
```

### Creating new user

On first launch application will ask you to provide some info.

#### Name

Just your name to get personalized experience. ☺️

#### CodeForces level

To start your CodeForces journey with octo-train you must specify level of problems you can solve.

You can either specify 0 and start from the easiest ones (you can change it in the settings later) or go to codeforces/archive and find appropriate level for you.


>⚠️ Problems level is the number specified on the right from problem's name. It starts at 500 and goes up to 3000 with step of 100.

![problems level](https://raw.githubusercontent.com/dankondr/octo-train/master/art/cf_problem_level.png)

#### CodeForces daily goal

The minimal number of problems you want to solve every day.

#### Project Euler level

With Project Euler you must specify level of problems you can solve too.

You can either specify 0 and start from the easiest ones (you can change it in the settings later) or go to projecteuler/archives and find appropriate level for you.


>⚠️ Problems level is the orange bar on the right from problem's name. Hover to see the number. It starts at 5% and goes up to 100%.

![problems level](https://raw.githubusercontent.com/dankondr/octo-train/master/art/pe_problem_level.png)

#### Project Euler daily goal

The minimal number of problems you want to solve every day.

### Get the problem

In menu select which kind of problems you want to solve.

![octo-train menu](https://raw.githubusercontent.com/dankondr/octo-train/master/art/octo-train-menu.gif)

### See the stats

Show your stats as a problem-solver.
